"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.cleanExternalMocks = exports.createMock = void 0;
var express_1 = __importDefault(require("express"));
var externalMocks = [];
var ExternalResponse = /** @class */ (function () {
    function ExternalResponse(app, method, route) {
        this.app = app;
        this.method = method;
        this.route = route;
        this.spyFn = undefined;
    }
    ExternalResponse.prototype.spy = function (fn) {
        this.spyFn = fn;
        return this;
    };
    ExternalResponse.prototype.reply = function (code, body) {
        var _this = this;
        this.app[this.method](this.route, function (req, res) {
            if (_this.spyFn) {
                _this.spyFn(req.body);
            }
            if (!body) {
                return res.sendStatus(code);
            }
            return res.status(code).send(body);
        });
    };
    return ExternalResponse;
}());
var ExternalMock = /** @class */ (function () {
    function ExternalMock(port) {
        this.app = (0, express_1["default"])();
        this.app.use(express_1["default"].json());
        this.server = this.app.listen(port);
    }
    ExternalMock.prototype.close = function () {
        this.server.close();
    };
    ExternalMock.prototype.get = function (route) {
        return new ExternalResponse(this.app, 'get', route);
    };
    ExternalMock.prototype.post = function (route) {
        return new ExternalResponse(this.app, 'post', route);
    };
    ExternalMock.prototype.put = function (route) {
        return new ExternalResponse(this.app, 'put', route);
    };
    ExternalMock.prototype.patch = function (route) {
        return new ExternalResponse(this.app, 'patch', route);
    };
    ExternalMock.prototype["delete"] = function (route) {
        return new ExternalResponse(this.app, 'delete', route);
    };
    return ExternalMock;
}());
var createMock = function (port) {
    var externalMock = new ExternalMock(port);
    externalMocks.push(externalMock);
    return externalMock;
};
exports.createMock = createMock;
var cleanExternalMocks = function () {
    externalMocks.forEach(function (server) { return server.close(); });
};
exports.cleanExternalMocks = cleanExternalMocks;
